@@ -116,8 +116,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_PIPED_FNAME      "syntax-by-name"
 #define OPT_ISOLATE_TAGS     "isolate"
 #define OPT_MAX_FILE_SIZE    "max-size"
-//#define OPT_TWO_PASS         "two-pass"
-
 
 // Improve CLI option compatibility with GNU source-highlight
 #define OPT_COMPAT_DOC       "doc"
@@ -291,6 +289,12 @@ public:
         {
         return opt_encoding_explicit;
     }
+   
+    /** \return True if style was defined by user*/
+    bool styleDefined() const
+    {
+        return !styleName.empty();
+    }
     
     /** \return True if output should be generated if language type is unknown*/
     bool forceOutput() const;
@@ -352,8 +356,9 @@ public:
     /** \return list of astyle options */
     const vector <string> &getAStyleOptions() const;
         
-    /** \return True if trailing nl should be omitted */
-    bool disableTrailingNL() const ;
+    /** \return 1 if trailing nl should be omitted, 
+     *          2 if it should only be ommitted for empty input */
+    int disableTrailingNL() const ;
 
     /** \return The given base font size, empty string by default */
     const string& getBaseFontSize() const ;
@@ -420,6 +425,7 @@ private:
     int lineNrStart;    // line number start count
     int lineRangeStart;    // line range start 
     int lineRangeEnd;    // line range end
+    int opt_no_trailing_nl;
 
     unsigned int canvasPaddingWidth;    // line number start count
 
@@ -484,7 +490,6 @@ private:
     bool opt_delim_CR;
     bool opt_print_style;
     bool opt_base16_theme;
-    bool opt_no_trailing_nl;
     bool opt_keep_injections;
     bool opt_force_stdout;
     bool opt_no_version_info;
