@@ -72,7 +72,7 @@ private:
 
     /** print input and output errors */
     void printIOErrorReport ( unsigned int numberErrorFiles, vector<string> & fileList, 
-                              const string &action );
+                              const string &action, const string &streamName );
 
     /** list installed  files
         \return true if files were found
@@ -86,6 +86,8 @@ private:
     */
     void printDebugInfo ( const highlight::SyntaxReader *lang,
                           const string &langDefPath );
+    
+    void printPersistentStates ( const highlight::SyntaxReader *lang);
 
     int getNumDigits ( int i );
 
