@@ -146,13 +146,14 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      maxLineCnt ( UINT_MAX ),
      inputFilesCnt (0),
      processedFilesCnt (0),
+     noTrailingNewLine(0),
+
      terminatingChar ( '\0' ),
      formatter ( NULL ),
      formattingEnabled ( false ),
      formattingPossible ( false ),
      validateInput ( false ),
      numberWrappedLines ( true ),
-     noTrailingNewLine(false),
      resultOfHook(false),
      lineContainedTestCase(false),
      applySyntaxTestCase(false),
@@ -225,7 +226,7 @@ void CodeGenerator::setIncludeStyle ( bool flag )
     includeStyleDef = flag;
 }
 
-void CodeGenerator::disableTrailingNL ( bool flag )
+void CodeGenerator::disableTrailingNL ( int flag )
 {
     noTrailingNewLine = flag;
 }
@@ -566,6 +567,11 @@ unsigned char CodeGenerator::getInputChar()
 {
     // end of line?
     if ( lineIndex == line.length() ) {
+        
+        //more testing required:
+        if (outputType==ESC_TRUECOLOR || outputType==ESC_XTERM256)
+            lastLineLength=StringTools::utf8_strlen(line);
+        
         bool eof=false;
         if ( preFormatter.isEnabled() ) {
             if ( !preFormatter.hasMoreLines() ) {
@@ -574,7 +580,7 @@ unsigned char CodeGenerator::getInputChar()
                 ++lineNumber;
                 numberCurrentLine = true;
             } else {
-                if(numberWrappedLines)
+                if (numberWrappedLines)
                     ++lineNumber;
                 numberCurrentLine = numberWrappedLines;
             }
@@ -586,7 +592,6 @@ unsigned char CodeGenerator::getInputChar()
 
             numberCurrentLine = true;
         }
-        lastLineLength=lineIndex;
         lineIndex=0;
         
         if (!lineContainedTestCase && applySyntaxTestCase){
@@ -752,19 +757,21 @@ void CodeGenerator::maskString ( ostream& ss, const string & s )
 {
     for ( unsigned int i=0; i< s.length(); i++ ) {
         ss << maskCharacter ( s[i] );
-
-        // do not add a trace indicator state for each byte of a UTF-8 sequence, only for the seq start
-        // https://stackoverflow.com/questions/4063146/getting-the-actual-length-of-a-utf-8-encoded-stdstring
-        //if ( applySyntaxTestCase && ( (s[i]&0xff) != 0xC2  || StringTools::change_case(encoding) !="utf-8" ) /*&& ( (s[i] & 0xc0) != 0x80 || StringTools::change_case(encoding) !="utf-8" ) */ ) {
-        if ( applySyntaxTestCase && ( (s[i] & 0xc0) != 0x80  || StringTools::change_case(encoding) !="utf-8" ) /*&& ( (s[i] & 0xc0) != 0x80 || StringTools::change_case(encoding) !="utf-8" ) */ ) {
-            
-            PositionState ps(currentState, getCurrentKeywordClassId(), false);
-            stateTraceCurrent.push_back(ps);
-            
-            if (stateTraceCurrent.size()>200) 
-                stateTraceCurrent.erase(stateTraceCurrent.begin(), stateTraceCurrent.begin() + 100 ); 
-        } 
     }
+    
+    // The test markers position should also be deternmined by calculating the code points
+    if ( applySyntaxTestCase ) {
+            
+        PositionState ps(currentState, getCurrentKeywordClassId(), false);
+        
+        int slen = encoding=="utf-8" ? StringTools::utf8_strlen(s) : s.length();  
+        for (int i=0; i< slen; i++ ) {
+            stateTraceCurrent.push_back(ps);
+        }
+        if (stateTraceCurrent.size()>200) 
+            stateTraceCurrent.erase(stateTraceCurrent.begin(), stateTraceCurrent.begin() + 100 ); 
+    } 
+    
 }
 
 
@@ -1787,8 +1794,9 @@ void CodeGenerator::processRootState()
             break;
         default:
             
-            if ((outputType==ESC_TRUECOLOR || outputType==ESC_XTERM256) && token.size())
-                openTag ( STANDARD );
+         // breaks Unicode sequences:
+         //   if ((outputType==ESC_TRUECOLOR || outputType==ESC_XTERM256) && token.size())
+           //     openTag ( STANDARD );
 
             printMaskedToken ();
             break;
@@ -1805,7 +1813,7 @@ void CodeGenerator::processRootState()
         }
     }
 
-    printNewLines = !noTrailingNewLine;
+    printNewLines = noTrailingNewLine==0 || ( noTrailingNewLine==2 && ( token.size() || lineNumber>1) );
     *out << getNewLine();
     *out << flush;
 }
@@ -2338,10 +2346,10 @@ void CodeGenerator::flushWs(int arg)
     }
      
      //fix canvas whitespace
-     if (outputType==ESC_XTERM256 || outputType==ESC_TRUECOLOR){
+    if (outputType==ESC_XTERM256 || outputType==ESC_TRUECOLOR){
         *out<< maskWsBegin;
-     }
-    
+    }
+     
     *out<<wsBuffer;
     wsBuffer.clear();
 }
@@ -2405,6 +2413,9 @@ void CodeGenerator::printTrace(const string &s){
 //column: lineIndex (not a UTF-8 validated string position)
 void CodeGenerator::runSyntaxTestcases(unsigned int column){
     
+    if (encoding=="utf-8")
+        column = StringTools::utf8_strlen(line.substr(0, column));
+    
     unsigned int assertGroup=0;
     size_t typeDescPos=line.find_first_not_of("\t ^", lineIndex);
     State assertState=_UNKNOWN;
